import { EventDispatcher, Quaternion, Vector3 } from "three";
import { Settings } from "../settings/Settings";
import { Disposable } from "./Disposable";
import { Updatable } from "./Updatable";
/**
 * Spatial controls for 3D translation and rotation.
 *
 * This class emits "update" events when the position or quaternion is changed.
 */
export declare class SpatialControls extends EventDispatcher implements Disposable, EventListenerObject, Updatable {
    /**
     * A DOM element. Acts as the primary event target.
     */
    private domElement;
    /**
     * The position that will be modified.
     */
    private position;
    /**
     * The quaternion that will be modified.
     */
    private quaternion;
    /**
     * The target.
     */
    private target;
    /**
     * The previous position.
     */
    private previousPosition;
    /**
     * The previous quaternion.
     */
    private previousQuaternion;
    /**
     * The previous target.
     */
    private previousTarget;
    /**
     * A rotation manager.
     */
    private rotationManager;
    /**
     * A translation manager.
     */
    private translationManager;
    /**
     * A map that links actions to specific strategies.
     */
    private strategies;
    /**
     * Indicates whether the user is currently holding the pointer button down.
     */
    private dragging;
    /**
     * The internal enabled state.
     */
    private enabled;
    /**
     * The control settings.
     */
    readonly settings: Settings;
    /**
     * Constructs new controls.
     *
     * @param position - A position.
     * @param quaternion - A quaternion.
     * @param domElement - A DOM element. Serves as the primary event target.
     */
    constructor(position?: Vector3, quaternion?: Quaternion, domElement?: HTMLElement);
    /**
     * Returns the DOM element.
     *
     * @return The DOM element.
     */
    getDomElement(): HTMLElement;
    /**
     * Sets the DOM element.
     *
     * @param domElement - The new DOM element.
     * @return This instance.
     */
    setDomElement(domElement: HTMLElement): SpatialControls;
    /**
     * Returns the position.
     *
     * @return The position.
     */
    getPosition(): Vector3;
    /**
     * Sets the position.
     *
     * @param x - The X-coordinate, or a new position vector.
     * @param y - The Y-coordinate.
     * @param z - The Z-coordinate.
     * @return This instance.
     */
    setPosition(x: number | Vector3, y?: number, z?: number): SpatialControls;
    /**
     * Returns the quaternion.
     *
     * @return The quaternion.
     */
    getQuaternion(): Quaternion;
    /**
     * Sets the quaternion.
     *
     * @param quaternion - The new quaternion.
     * @return This instance.
     */
    setQuaternion(quaternion: Quaternion): SpatialControls;
    /**
     * Returns the target.
     *
     * @return The target.
     */
    getTarget(): Vector3;
    /**
     * Sets the target.
     *
     * @param x - The X-coordinate, or a new target vector.
     * @param y - The Y-coordinate.
     * @param z - The Z-coordinate.
     * @return This instance.
     */
    setTarget(x: number | Vector3, y?: number, z?: number): SpatialControls;
    /**
     * Looks at the given point.
     *
     * @param x - The X-coordinate, or a point.
     * @param y - The Y-coordinate.
     * @param z - The Z-coordinate.
     * @return This instance.
     */
    lookAt(x: number | Vector3, y?: number, z?: number): SpatialControls;
    /**
     * Returns the current view direction.
     *
     * @param view - A vector to store the direction in.
     * @return The normalized view direction.
     */
    getViewDirection(view: Vector3): Vector3;
    /**
     * Indicates whether the controls are enabled.
     *
     * @return Whether the controls are enabled.
     */
    isEnabled(): boolean;
    /**
     * Enables or disables the controls.
     *
     * @param enabled - Whether the controls should be enabled or disabled.
     * @return This instance.
     */
    setEnabled(enabled?: boolean): SpatialControls;
    /**
     * Copies the given controls.
     *
     * @param controls - A controls instance.
     * @return This instance.
     */
    copy(controls: SpatialControls): SpatialControls;
    /**
     * Clones this instance.
     *
     * @return The cloned controls.
     */
    clone(): SpatialControls;
    /**
     * Locks or unlocks the pointer.
     *
     * @param locked - Whether the pointer should be locked.
     */
    setPointerLocked(locked?: boolean): void;
    /**
     * Enables or disables the rotation mode.
     *
     * @param pressed - Whether the rotation mode should be activated.
     */
    setRotationEnabled(enabled: boolean): void;
    /**
     * Handles pointer move events.
     *
     * @param event - A pointer event.
     */
    private handlePointerMoveEvent;
    /**
     * Handles pointer button events.
     *
     * @param event - A pointer event.
     * @param pressed - Whether the pointer button has been pressed down.
     */
    private handlePointerButtonEvent;
    /**
     * Handles pointer cancel and leave events.
     *
     * @param event - A pointer event.
     */
    private handlePointerCancelEvent;
    /**
     * Handles wheel events.
     *
     * @param event - A wheel event.
     */
    private handleWheelEvent;
    /**
     * Handles keyboard events.
     *
     * @param event - A keyboard event.
     * @param pressed - Whether the key has been pressed down.
     */
    private handleKeyboardEvent;
    /**
     * Enables or disables controls based on the pointer lock state.
     */
    private handlePointerLockEvent;
    /**
     * Cancels active interactions on visibility loss.
     */
    private handleVisibilityChangeEvent;
    /**
     * Reacts to setting changes.
     *
     * @param event - An event.
     */
    private onSettingsChanged;
    /**
     * Synchronizes the internal state with external changes.
     */
    private synchronize;
    handleEvent(event: Event): void;
    update(timestamp: number): void;
    dispose(): void;
}
