import { EventDispatcher, Quaternion, Vector3 } from "three";
import { Updatable } from "../core";
import { Settings } from "../settings";
/**
 * A rotation manager.
 */
export declare class RotationManager extends EventDispatcher implements Updatable {
    /**
     * The position that will be modified.
     */
    private position;
    /**
     * The quaternion that will be modified.
     */
    private quaternion;
    /**
     * The target.
     */
    private target;
    /**
     * The settings.
     */
    private settings;
    /**
     * The current spherical coordinates.
     */
    private spherical0;
    /**
     * The spherical target coordinates.
     */
    private spherical1;
    /**
     * Scalar dampers.
     */
    private scalarDampers;
    /**
     * A timestamp.
     */
    private timestamp;
    /**
     * A reusable update event.
     */
    private updateEvent;
    /**
     * Constructs a new rotation manager.
     *
     * @param position - The position.
     * @param quaternion - The quaternion.
     * @param target - The target.
     * @param settings - The settings.
     */
    constructor(position: Vector3, quaternion: Quaternion, target: Vector3, settings: Settings);
    /**
     * Sets the position.
     *
     * @param position - A position.
     * @return This manager.
     */
    setPosition(position: Vector3): RotationManager;
    /**
     * Sets the quaternion.
     *
     * @param quaternion - A quaternion.
     * @return This manager.
     */
    setQuaternion(quaternion: Quaternion): RotationManager;
    /**
     * Sets the target.
     *
     * @param target - A target.
     * @return This manager.
     */
    setTarget(target: Vector3): RotationManager;
    /**
     * Resets the current velocity.
     *
     * @return This manager.
     */
    resetVelocity(): void;
    /**
     * Restricts the spherical angles.
     *
     * @return This manager.
     */
    private restrictAngles;
    /**
     * Restricts the spherical radius.
     *
     * @return This manager.
     */
    private restrictRadius;
    /**
     * Returns the current radius.
     *
     * @return The radius.
     */
    getRadius(): number;
    /**
     * Restricts the spherical system.
     *
     * @return This manager.
     */
    restrictSpherical(): RotationManager;
    /**
     * Updates the spherical coordinates based on the position and target.
     *
     * @return This manager.
     */
    updateSpherical(): RotationManager;
    /**
     * Updates the position based on the spherical coordinates.
     *
     * @return This manager.
     */
    updatePosition(): RotationManager;
    /**
     * Updates the quaternion.
     *
     * @return This manager.
     */
    updateQuaternion(): RotationManager;
    /**
     * Adjusts the spherical system.
     *
     * @param theta - The angle to add to theta in radians.
     * @param phi - The angle to add to phi in radians.
     * @return This manager.
     */
    adjustSpherical(theta: number, phi: number): RotationManager;
    /**
     * Zooms in or out. Only applies in third person mode.
     *
     * @param sign - The zoom sign. Possible values are [-1, 0, 1].
     * @return This manager.
     */
    zoom(sign: number): RotationManager;
    /**
     * Looks at the given point.
     *
     * @param point - The target point.
     * @return This manager.
     */
    lookAt(point: Vector3): RotationManager;
    /**
     * Returns the current view direction.
     *
     * @param view - A vector to store the direction in.
     * @return The normalized view direction.
     */
    getViewDirection(view: Vector3): Vector3;
    update(timestamp: number): void;
}
