import { EventDispatcher, Vector3 } from "three";
/**
 * JSON representation of rotation settings.
 */
export interface RotationSettingsJSON {
    up: Vector3;
    pivotOffset: Vector3;
    minAzimuthalAngle: number;
    maxAzimuthalAngle: number;
    minPolarAngle: number;
    maxPolarAngle: number;
    invertedX: boolean;
    invertedY: boolean;
    sensitivityX: number;
    sensitivityY: number;
    damping: number;
}
/**
 * Rotation settings.
 */
export declare class RotationSettings extends EventDispatcher {
    /**
     * The up vector. Must be normalized.
     */
    private up;
    /**
     * A pivot offset. Only affects third person orbiting.
     */
    private pivotOffset;
    /**
     * The minimum azimuthal angle in radians.
     */
    private minAzimuthalAngle;
    /**
     * The maximum azimuthal angle in radians.
     */
    private maxAzimuthalAngle;
    /**
     * The minimum polar angle in radians.
     */
    private minPolarAngle;
    /**
     * The maximum polar angle in radians.
     */
    private maxPolarAngle;
    /**
     * Indicates whether the horizontal rotation is inverted.
     */
    private invertedX;
    /**
     * Indicates whether the vertical rotation is inverted.
     */
    private invertedY;
    /**
     * The horizontal rotation sensitivity.
     */
    private sensitivityX;
    /**
     * The vertical rotation sensitivity.
     */
    private sensitivityY;
    /**
     * The damping factor. Range is [0.0, +Infinity]. Set to 0 to disable.
     */
    private damping;
    /**
     * Constructs new rotation settings.
     */
    constructor();
    /**
     * Returns the up vector offset.
     *
     * @return The up vector.
     */
    getUpVector(): Vector3;
    /**
     * Sets the up vector.
     *
     * @param value - The up vector.
     */
    setUpVector(value: Vector3): void;
    /**
     * Returns the pivot offset.
     *
     * @return The offset.
     */
    getPivotOffset(): Vector3;
    /**
     * Sets the pivot offset.
     *
     * @param value - The offset.
     */
    setPivotOffset(value: Vector3): void;
    /**
     * Returns the minimum azimuthal angle in radians.
     *
     * @return The angle.
     */
    getMinAzimuthalAngle(): number;
    /**
     * Sets the minimum azimuthal angle in radians. Range: [-Math.PI, Math.PI].
     *
     * @param value - The angle.
     */
    setMinAzimuthalAngle(value: number): void;
    /**
     * Returns the maximum azimuthal angle in radians.
     *
     * @return The angle.
     */
    getMaxAzimuthalAngle(): number;
    /**
     * Sets the maximum azimuthal angle in radians. Range: [-Math.PI, Math.PI].
     *
     * @param value - The angle.
     */
    setMaxAzimuthalAngle(value: number): void;
    /**
     * Returns the minimum polar angle in radians.
     *
     * @return The angle.
     */
    getMinPolarAngle(): number;
    /**
     * Sets the minimum polar angle in radians. Range: [0, Math.PI].
     *
     * @param value - The angle.
     */
    setMinPolarAngle(value: number): void;
    /**
     * Returns the maximum polar angle in radians.
     *
     * @return The angle.
     */
    getMaxPolarAngle(): number;
    /**
     * Sets the maximum polar angle in radians. Range: [0, Math.PI].
     *
     * @param value - The angle.
     */
    setMaxPolarAngle(value: number): void;
    /**
     * Indicates whether the horizontal rotation is inverted.
     *
     * @return Whether the horizontal rotation is inverted.
     */
    isInvertedX(): boolean;
    /**
     * Defines whether the horizontal rotation should be inverted.
     *
     * @param value - The value.
     */
    setInvertedX(value: boolean): void;
    /**
     * Indicates whether the vertical rotation is inverted.
     *
     * @return Whether the vertical rotation is inverted.
     */
    isInvertedY(): boolean;
    /**
     * Defines whether the vertical rotation should be inverted.
     *
     * @param value - The value.
     */
    setInvertedY(value: boolean): void;
    /**
     * Returns the horizontal rotation sensitivity.
     *
     * @return The sensitivity.
     */
    getSensitivityX(): number;
    /**
     * Sets the horizontal rotation sensitivity.
     *
     * @param value - The sensitivity.
     */
    setSensitivityX(value: number): void;
    /**
     * Returns the vertical rotation sensitivity.
     *
     * @return The sensitivity.
     */
    getSensitivityY(): number;
    /**
     * Sets the vertical rotation sensitivity.
     *
     * @param value - The sensitivity.
     */
    setSensitivityY(value: number): void;
    /**
     * Sets the rotation sensitivity.
     *
     * @param value - The sensitivity.
     */
    setSensitivity(value: number): void;
    /**
     * Returns the damping factor.
     *
     * @return The damping factor.
     */
    getDamping(): number;
    /**
     * Sets the damping factor.
     *
     * @param value - The damping factor.
     */
    setDamping(value: number): void;
    /**
     * Copies the given rotation settings.
     *
     * @param settings - Rotation settings.
     * @return This instance.
     */
    copy(settings: RotationSettings): RotationSettings;
    /**
     * Clones this rotation settings instance.
     *
     * @return The cloned rotation settings.
     */
    clone(): RotationSettings;
    /**
     * Copies the given JSON data.
     *
     * @param json - The JSON data.
     * @return This instance.
     */
    fromJSON(json: RotationSettingsJSON): RotationSettings;
    toJSON(): Record<string, unknown>;
}
