import { EventDispatcher } from "three";
/**
 * JSON representation of translation settings.
 */
export interface TranslationSettingsJSON {
    enabled: boolean;
    sensitivity: number;
    boostMultiplier: number;
    damping: number;
}
/**
 * Translation settings.
 */
export declare class TranslationSettings extends EventDispatcher {
    /**
     * Whether positional translation is enabled.
     */
    private enabled;
    /**
     * The translation sensitivity.
     */
    private sensitivity;
    /**
     * The translation boost multiplier.
     */
    private boostMultiplier;
    /**
     * The damping factor. Range is [0.0, +Infinity]. Set to 0 to disable.
     */
    private damping;
    /**
     * Constructs new translation settings.
     */
    constructor();
    /**
     * Indicates whether translation is enabled.
     *
     * @return Whether translation is enabled.
     */
    isEnabled(): boolean;
    /**
     * Enables or disables translation.
     *
     * @param value - The value.
     */
    setEnabled(value: boolean): void;
    /**
     * Returns the translation sensitivity.
     *
     * @return The sensitivity.
     */
    getSensitivity(): number;
    /**
     * Sets the translation sensitivity.
     *
     * @param value - The sensitivity.
     */
    setSensitivity(value: number): void;
    /**
     * Returns the translation boost multiplier.
     *
     * @return The multiplier.
     */
    getBoostMultiplier(): number;
    /**
     * Sets the translation boost multiplier.
     *
     * @param value - The multiplier. Must be >= 1.
     */
    setBoostMultiplier(value: number): void;
    /**
     * Returns the damping factor.
     *
     * @return The damping factor.
     */
    getDamping(): number;
    /**
     * Sets the damping factor.
     *
     * @param value - The damping factor.
     */
    setDamping(value: number): void;
    /**
     * Copies the given translation settings.
     *
     * @param settings - Translation settings.
     * @return This instance.
     */
    copy(settings: TranslationSettings): TranslationSettings;
    /**
     * Clones this translation settings instance.
     *
     * @return The cloned translation settings.
     */
    clone(): TranslationSettings;
    /**
     * Copies the given JSON data.
     *
     * @param json - The JSON data.
     * @return This instance.
     */
    fromJSON(json: TranslationSettingsJSON): TranslationSettings;
    toJSON(): Record<string, unknown>;
}
