import { EventDispatcher } from "three";
/**
 * JSON representation of zoom settings.
 */
export interface ZoomSettingsJSON {
    enabled: boolean;
    inverted: boolean;
    minDistance: number;
    maxDistance: number;
    sensitivity: number;
    damping: number;
}
/**
 * Zoom settings.
 */
export declare class ZoomSettings extends EventDispatcher {
    /**
     * Whether zooming is enabled.
     */
    private enabled;
    /**
     * Indicates whether the zoom controls should be inverted.
     */
    private inverted;
    /**
     * The minimum zoom distance.
     */
    private minDistance;
    /**
     * The maximum zoom distance.
     */
    private maxDistance;
    /**
     * The zoom sensitivity.
     */
    private sensitivity;
    /**
     * The damping factor. Range is [0.0, +Infinity]. Set to 0 to disable.
     */
    private damping;
    /**
     * Constructs new zoom settings.
     */
    constructor();
    /**
     * Indicates whether zooming is enabled.
     *
     * @return Whether zooming is enabled.
     */
    isEnabled(): boolean;
    /**
     * Enables or disables zooming.
     *
     * @param value - The value.
     */
    setEnabled(value: boolean): void;
    /**
     * Indicates whether the zoom controls should be inverted.
     *
     * @return Whether zooming is enabled.
     */
    isInverted(): boolean;
    /**
     * Defines whether the zoom controls should be inverted.
     *
     * @param value - The value.
     */
    setInverted(value: boolean): void;
    /**
     * Returns the minimum zoom distance.
     *
     * @return The distance.
     */
    getMinDistance(): number;
    /**
     * Sets the minimum zoom distance.
     *
     * @param value - The distance. Must be greater than zero.
     */
    setMinDistance(value: number): void;
    /**
     * Returns the maximum zoom distance.
     *
     * @return The distance.
     */
    getMaxDistance(): number;
    /**
     * Sets the maximum zoom distance.
     *
     * @param value - The distance. Must be greater than the minimum distance.
     */
    setMaxDistance(value: number): void;
    /**
     * Sets the minimum and maximum zoom distance.
     *
     * @param min - The minimum distance.
     * @param max - The maximum distance.
     */
    setRange(min: number, max: number): void;
    /**
     * Returns the zoom sensitivity.
     *
     * @return The sensitivity.
     */
    getSensitivity(): number;
    /**
     * Sets the zoom sensitivity.
     *
     * @param value - The sensitivity.
     */
    setSensitivity(value: number): void;
    /**
     * Returns the damping factor.
     *
     * @return The damping factor.
     */
    getDamping(): number;
    /**
     * Sets the damping factor.
     *
     * @param value - The damping factor.
     */
    setDamping(value: number): void;
    /**
     * Copies the given zoom settings.
     *
     * @param settings - Zoom settings.
     * @return This instance.
     */
    copy(settings: ZoomSettings): ZoomSettings;
    /**
     * Clones this zoom settings instance.
     *
     * @return The cloned zoom settings.
     */
    clone(): ZoomSettings;
    /**
     * Copies the given JSON data.
     *
     * @param json - The JSON data.
     * @return This instance.
     */
    fromJSON(json: ZoomSettingsJSON): ZoomSettings;
    toJSON(): Record<string, unknown>;
}
